==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExpressRouteLinkMacSecConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ExpressRouteLinkMacSecCipher
import com.pulumi.azurenative.network.kotlin.enums.ExpressRouteLinkMacSecSciState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ExpressRouteLink Mac Security Configuration.
 * @property cakSecretIdentifier Keyvault Secret Identifier URL containing Mac security CAK key.
 * @property cipher Mac security cipher.
 * @property cknSecretIdentifier Keyvault Secret Identifier URL containing Mac security CKN key.
 * @property sciState Sci mode enabled/disabled.
 */
public data class ExpressRouteLinkMacSecConfigArgs(
    public val cakSecretIdentifier: Output<String>? = null,
    public val cipher: Output<Either<String, ExpressRouteLinkMacSecCipher>>? = null,
    public val cknSecretIdentifier: Output<String>? = null,
    public val sciState: Output<Either<String, ExpressRouteLinkMacSecSciState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs =
        com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs.builder()
            .cakSecretIdentifier(cakSecretIdentifier?.applyValue({ args0 -> args0 }))
            .cipher(
                cipher?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cknSecretIdentifier(cknSecretIdentifier?.applyValue({ args0 -> args0 }))
            .sciState(
                sciState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExpressRouteLinkMacSecConfigArgs].
 */
@PulumiTagMarker
public class ExpressRouteLinkMacSecConfigArgsBuilder internal constructor() {
    private var cakSecretIdentifier: Output<String>? = null

    private var cipher: Output<Either<String, ExpressRouteLinkMacSecCipher>>? = null

    private var cknSecretIdentifier: Output<String>? = null

    private var sciState: Output<Either<String, ExpressRouteLinkMacSecSciState>>? = null

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CAK key.
     */
    @JvmName("hvejdwmcalfmhsya")
    public suspend fun cakSecretIdentifier(`value`: Output<String>) {
        this.cakSecretIdentifier = value
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("xugivgfmbhfdsgim")
    public suspend fun cipher(`value`: Output<Either<String, ExpressRouteLinkMacSecCipher>>) {
        this.cipher = value
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CKN key.
     */
    @JvmName("dvdldwrlkjcbpwcv")
    public suspend fun cknSecretIdentifier(`value`: Output<String>) {
        this.cknSecretIdentifier = value
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("nwegbxybudatgqyc")
    public suspend fun sciState(`value`: Output<Either<String, ExpressRouteLinkMacSecSciState>>) {
        this.sciState = value
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CAK key.
     */
    @JvmName("wgomqwxfiodfmexw")
    public suspend fun cakSecretIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cakSecretIdentifier = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("jmpbpgpywoqplfcw")
    public suspend fun cipher(`value`: Either<String, ExpressRouteLinkMacSecCipher>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("jgijmxpnwkkqwwcw")
    public fun cipher(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressRouteLinkMacSecCipher>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("ngjyhtrsyxbyifdn")
    public fun cipher(`value`: ExpressRouteLinkMacSecCipher) {
        val toBeMapped = Either.ofRight<String, ExpressRouteLinkMacSecCipher>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CKN key.
     */
    @JvmName("vrhvnylnpmjtlfqt")
    public suspend fun cknSecretIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cknSecretIdentifier = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("aadixesgurvunvwu")
    public suspend fun sciState(`value`: Either<String, ExpressRouteLinkMacSecSciState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("knwuajoemgbeitsh")
    public fun sciState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressRouteLinkMacSecSciState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("ivgoqlhnglsuvlyu")
    public fun sciState(`value`: ExpressRouteLinkMacSecSciState) {
        val toBeMapped = Either.ofRight<String, ExpressRouteLinkMacSecSciState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    internal fun build(): ExpressRouteLinkMacSecConfigArgs = ExpressRouteLinkMacSecConfigArgs(
        cakSecretIdentifier = cakSecretIdentifier,
        cipher = cipher,
        cknSecretIdentifier = cknSecretIdentifier,
        sciState = sciState,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/inputs/ExpressRouteLinkMacSecConfigArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.inputs

import com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs.builder
import com.pulumi.azurenative.network.kotlin.enums.ExpressRouteLinkMacSecCipher
import com.pulumi.azurenative.network.kotlin.enums.ExpressRouteLinkMacSecSciState
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * ExpressRouteLink Mac Security Configuration.
 * @property cakSecretIdentifier Keyvault Secret Identifier URL containing Mac security CAK key.
 * @property cipher Mac security cipher.
 * @property cknSecretIdentifier Keyvault Secret Identifier URL containing Mac security CKN key.
 * @property sciState Sci mode enabled/disabled.
 */
public data class ExpressRouteLinkMacSecConfigArgs(
    public val cakSecretIdentifier: Output<String>? = null,
    public val cipher: Output<Either<String, ExpressRouteLinkMacSecCipher>>? = null,
    public val cknSecretIdentifier: Output<String>? = null,
    public val sciState: Output<Either<String, ExpressRouteLinkMacSecSciState>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs> {
    override fun toJava(): com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs =
        com.pulumi.azurenative.network.inputs.ExpressRouteLinkMacSecConfigArgs.builder()
            .cakSecretIdentifier(cakSecretIdentifier?.applyValue({ args0 -> args0 }))
            .cipher(
                cipher?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .cknSecretIdentifier(cknSecretIdentifier?.applyValue({ args0 -> args0 }))
            .sciState(
                sciState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [ExpressRouteLinkMacSecConfigArgs].
 */
@PulumiTagMarker
public class ExpressRouteLinkMacSecConfigArgsBuilder internal constructor() {
    private var cakSecretIdentifier: Output<String>? = null

    private var cipher: Output<Either<String, ExpressRouteLinkMacSecCipher>>? = null

    private var cknSecretIdentifier: Output<String>? = null

    private var sciState: Output<Either<String, ExpressRouteLinkMacSecSciState>>? = null

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CAK key.
     */
    @JvmName("ohmnefmwhxntrgha")
    public suspend fun cakSecretIdentifier(`value`: Output<String>) {
        this.cakSecretIdentifier = value
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("rlbtlsxxcxqnoids")
    public suspend fun cipher(`value`: Output<Either<String, ExpressRouteLinkMacSecCipher>>) {
        this.cipher = value
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CKN key.
     */
    @JvmName("mijxfqjhacpaspuu")
    public suspend fun cknSecretIdentifier(`value`: Output<String>) {
        this.cknSecretIdentifier = value
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("woxujplwljqnbpxu")
    public suspend fun sciState(`value`: Output<Either<String, ExpressRouteLinkMacSecSciState>>) {
        this.sciState = value
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CAK key.
     */
    @JvmName("ciglcspclfdpekrv")
    public suspend fun cakSecretIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cakSecretIdentifier = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("vkspkkgevtnufnkr")
    public suspend fun cipher(`value`: Either<String, ExpressRouteLinkMacSecCipher>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("bbrercgdcpiguamo")
    public fun cipher(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressRouteLinkMacSecCipher>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Mac security cipher.
     */
    @JvmName("lhcxvyedaneqyyly")
    public fun cipher(`value`: ExpressRouteLinkMacSecCipher) {
        val toBeMapped = Either.ofRight<String, ExpressRouteLinkMacSecCipher>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.cipher = mapped
    }

    /**
     * @param value Keyvault Secret Identifier URL containing Mac security CKN key.
     */
    @JvmName("tfghaovjqnklmrrk")
    public suspend fun cknSecretIdentifier(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.cknSecretIdentifier = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("lfulekhmmthuqxcj")
    public suspend fun sciState(`value`: Either<String, ExpressRouteLinkMacSecSciState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("ggprirrccjsaffof")
    public fun sciState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ExpressRouteLinkMacSecSciState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    /**
     * @param value Sci mode enabled/disabled.
     */
    @JvmName("bmgsmdihsskogmnk")
    public fun sciState(`value`: ExpressRouteLinkMacSecSciState) {
        val toBeMapped = Either.ofRight<String, ExpressRouteLinkMacSecSciState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sciState = mapped
    }

    internal fun build(): ExpressRouteLinkMacSecConfigArgs = ExpressRouteLinkMacSecConfigArgs(
        cakSecretIdentifier = cakSecretIdentifier,
        cipher = cipher,
        cknSecretIdentifier = cknSecretIdentifier,
        sciState = sciState,
    )
}
